/*
 * Copyright (c) 2020 Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef BOARD_H
#define BOARD_H

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//
// Included Files
//

#include "driverlib.h"
#include "device.h"

//*****************************************************************************
//
// PinMux Configurations
//
//*****************************************************************************

//
// CANB -> myCAN Pinmux
//
//
// CANRXB - GPIO Settings
//
#define GPIO_PIN_CANRXB 17
#define myCAN_CANRX_GPIO 17
#define myCAN_CANRX_PIN_CONFIG GPIO_17_CANRXB
//
// CANTXB - GPIO Settings
//
#define GPIO_PIN_CANTXB 12
#define myCAN_CANTX_GPIO 12
#define myCAN_CANTX_PIN_CONFIG GPIO_12_CANTXB

//
// EPWM7 -> myEPWMTimer0 Pinmux
//
//
// EPWM7A - GPIO Settings
//
#define GPIO_PIN_EPWM7A 157
#define myEPWMTimer0_EPWMA_GPIO 157
#define myEPWMTimer0_EPWMA_PIN_CONFIG GPIO_157_EPWM7A
//
// EPWM7B - GPIO Settings
//
#define GPIO_PIN_EPWM7B 13
#define myEPWMTimer0_EPWMB_GPIO 13
#define myEPWMTimer0_EPWMB_PIN_CONFIG GPIO_13_EPWM7B
//
// GPIO34 - GPIO Settings
//
#define myLEDRed_GPIO_PIN_CONFIG GPIO_34_GPIO34
//
// GPIO95 - GPIO Settings
//
#define myButton_GPIO_PIN_CONFIG GPIO_95_GPIO95
//
// GPIO31 - GPIO Settings
//
#define myLEDBlue_GPIO_PIN_CONFIG GPIO_31_GPIO31
//
// GPIO32 - GPIO Settings
//
#define DEBUG2_GPIO_PIN_CONFIG GPIO_32_GPIO32
//
// GPIO67 - GPIO Settings
//
#define DEBUG5_GPIO_PIN_CONFIG GPIO_67_GPIO67

//*****************************************************************************
//
// CAN Configurations
//
//*****************************************************************************
#define myCAN_BASE CANB_BASE

#define myCAN_MessageObj1_ID 1024
void myCAN_init();


//*****************************************************************************
//
// CPUTIMER Configurations
//
//*****************************************************************************
#define myCPUTIMER0_BASE CPUTIMER0_BASE
void myCPUTIMER0_init();

//*****************************************************************************
//
// EPWM Configurations
//
//*****************************************************************************
#define myEPWMTimer0_BASE EPWM7_BASE
#define myEPWMTimer0_TBPRD 10000
#define myEPWMTimer0_COUNTER_MODE EPWM_COUNTER_MODE_UP
#define myEPWMTimer0_TBPHS 0
#define myEPWMTimer0_CMPA 0
#define myEPWMTimer0_CMPB 0
#define myEPWMTimer0_CMPC 0
#define myEPWMTimer0_CMPD 0
#define myEPWMTimer0_DBRED 0
#define myEPWMTimer0_DBFED 0
#define myEPWMTimer0_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWMTimer0_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWMTimer0_INTERRUPT_SOURCE EPWM_INT_TBCTR_PERIOD

//*****************************************************************************
//
// GPIO Configurations
//
//*****************************************************************************
#define myLEDRed 34
void myLEDRed_init();
#define myButton 95
void myButton_init();
#define myLEDBlue 31
void myLEDBlue_init();
#define DEBUG2 32
void DEBUG2_init();
#define DEBUG5 67
void DEBUG5_init();

//*****************************************************************************
//
// INPUTXBAR Configurations
//
//*****************************************************************************
#define myINPUTXBARINPUT0_SOURCE 15
#define myINPUTXBARINPUT0_INPUT XBAR_INPUT4
void myINPUTXBARINPUT0_init();
#define myINPUTXBARINPUT1_SOURCE 26
#define myINPUTXBARINPUT1_INPUT XBAR_INPUT5
void myINPUTXBARINPUT1_init();
#define myINPUTXBARINPUT2_SOURCE 95
#define myINPUTXBARINPUT2_INPUT XBAR_INPUT6
void myINPUTXBARINPUT2_init();

//*****************************************************************************
//
// INTERRUPT Configurations
//
//*****************************************************************************

// Interrupt Settings for INT_myCAN_0
#define INT_myCAN_0 INT_CANB0
#define INT_myCAN_0_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP9
extern __interrupt void INT_myCAN_0_ISR(void);

// Interrupt Settings for INT_myCAN_1
#define INT_myCAN_1 INT_CANB1
#define INT_myCAN_1_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP9
extern __interrupt void INT_myCAN_1_ISR(void);

// Interrupt Settings for INT_myCPUTIMER0
#define INT_myCPUTIMER0 INT_TIMER0
#define INT_myCPUTIMER0_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP1
extern __interrupt void INT_myCPUTIMER0_ISR(void);

// Interrupt Settings for INT_myEPWMTimer0
#define INT_myEPWMTimer0 INT_EPWM7
#define INT_myEPWMTimer0_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP3
extern __interrupt void INT_myEPWMTimer0_ISR(void);

// Interrupt Settings for INT_myButton_XINT
#define INT_myButton_XINT INT_XINT3
#define INT_myButton_XINT_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP12
extern __interrupt void INT_myButton_XINT_ISR(void);

//*****************************************************************************
//
// MEMCFG Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// SYNC Scheme Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// XINT Configurations
//
//*****************************************************************************
#define myButton_XINT GPIO_INT_XINT3
#define myButton_XINT_TYPE GPIO_INT_TYPE_FALLING_EDGE
void myButton_XINT_init();

//*****************************************************************************
//
// Board Configurations
//
//*****************************************************************************
void	Board_init();
void	CAN_init();
void	CPUTIMER_init();
void	EPWM_init();
void	GPIO_init();
void	INPUTXBAR_init();
void	INTERRUPT_init();
void	MEMCFG_init();
void	SYNC_init();
void	XINT_init();
void	PinMux_init();

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of BOARD_H definition
