/*
 * LIEB_FormatVariables.c
 *
 *  Created on: 26 janv. 2024
 *      Author: V.LIEBART
 *
 *      Ensemble de fonctions utilisateurs de mises en forme de variables
 *      - Rangement d'une variable dans un tableau d'lments de taille rduite
 *      - Conversion en chane de caractres
 *      - ...
 *
 */


#include "F28x_Project.h"                               // Dfinition types (sans"_t) pour CPU et CLA (redondant inclusions dans driverlib.h)
#include "driverlib.h"                                  // Inclusion des headers de tous les priphriques (ex.adc.h)


#include "LIEB_FormatVariables.h"


//*****************************************************************************
//
//! Range un Float32 dans un tableau octet par octet
//!
//! \flt_FloatToTab : Flottant  ranger dans le tableau
//! \Adr_TabUint16  : Adresse du tablau
//! \Position       : Position  laquelle ranger le flottant - Min=0
//!
//! Le tableau est un tablau de mots de 16bits (le plus petit adressage)
//! Le flottant est rang mot  mot dans le tableau  partir Position
//! Conversion en entier par fonction intrinsque pralable
//! - ne consomme pas de ressource autre que le transfert de variable
//! - permet au compilateur de traiter le flottant en entier (non ibligatoire)
//!
//! \return None.
//
//*****************************************************************************

void LIEB_FloatToUint8Tab(float32_t flt_FloatToTab,uint16_t * Adr_TabUint16,uint16_t Position)
{
    uint32_t uint32_FloatToTab=__f32_bits_as_u32(flt_FloatToTab);       // fonction intrinsque, pas de code (juste dire au compilateur comment interprter la variable)
    Adr_TabUint16[0+Position] = (0x000000FF & uint32_FloatToTab);
    Adr_TabUint16[1+Position] = (0x0000FF00 & uint32_FloatToTab)>>8;
    Adr_TabUint16[2+Position] = (0x00FF0000 & uint32_FloatToTab)>>16;
    Adr_TabUint16[3+Position] = (0xFF000000 & uint32_FloatToTab)>>24;


}
