//#############################################################################
//
// FILE:   empty_bitfield_driverlib_main.c
//
// TITLE:  Empty Example
//
// Empty Bit-Field & Driverlib Example
//
// This example is an empty project setup for Bit-Field and Driverlib 
// development.
//
//#############################################################################
//
// $Release Date: $
// $Copyright:
// Copyright (C) 2013-2023 Texas Instruments Incorporated - http://www.ti.com/
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions 
// are met:
// 
//   Redistributions of source code must retain the above copyright 
//   notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the 
//   documentation and/or other materials provided with the   
//   distribution.
// 
//   Neither the name of Texas Instruments Incorporated nor the names of
//   its contributors may be used to endorse or promote products derived
//   from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// $
//#############################################################################


/* ===================================================================================================================================
 * 12/2023 V LIEBART Supergrid-Institute
 * Projet Vide DriverLib+Bit-Field+SysConfig CPU1 Only
 * C2000Ware v5.0
 * SysConfigv17.0
 *
 * Notes:
 * - 2 fichiers de commande pour le linker: un slectionn pour la config RAM, l'autre pour la config FLASH
 * - la config FLASH s'accompagne de la macro _FLASH disponible pour tout le projet
 * - le fichier de commande Linker pour la cartographie RAM a t modifi pour un chargement d'un programme volumineux dans la RAM
 * - les 2 configs s'acompagnent de la macro CPU1 disponible pour tout le projet
 *
 * Exemple Fourni:
 * - BP  connecter sur LAUNCHXL entre GND et broche 42
 * - Chaque appui long sur BP permute l'tat de la LED Rouge
 * - Clignotement LED bleue #1s
 *
 * ===================================================================================================================================
 */



// TYPES STANDARDS A UTILISER (CPU)
// ==================================

/*
    typedef int                                     int16;
    typedef long                                    int32;
    typedef long long                               int64;
    typedef unsigned int                            Uint16;
    typedef unsigned long                           Uint32;
    typedef unsigned long long                      Uint64;
    typedef float                                   float32;
    typedef long double                             float64;

*/


// Included Files
// ===============

// Gnrique
// ----------

#include "F28x_Project.h"                               // Dfinition types (sans"_t) pour CPU et CLA (redondant inclusions dans driverlib.h)
#include "driverlib.h"                                  // Inclusion des headers de tous les priphriques (ex.adc.h)
#include "device.h"                                     // dfinition des paramtres horloge, utiliss par driverlib

#include "board.h"                                      // ATTENTION: le parser ouvre systmatiquement le fichier de la config RAM mais compilation avec le fichier de la config choisie
#include "c2000ware_libraries.h"

// Applicatif
// -----------
// Mettre ici les include utilisateur
#include "LIEB_FormatVariables.h"


// Prototypes de routines Interrupt
// ==================================
__interrupt void INT_myEPWMTimer0_ISR(void);
__interrupt void INT_myCAN_0_ISR(void);
__interrupt void INT_myCAN_1_ISR(void);

// Prototypes Externes
// =====================
// mettre ici en extern les prototypes des fonctions dfinis dans d'autres fichiers sources


// Variables Globales
// ==================================
uint16_t txMsgData[8];
uint16_t rxMsgData[8];
float32 flt_CANTX;



//
// Main
//
void main(void)
{


    // INITIALISATIONS MINIMALES
    // --------------------------
    Device_init();                                                              // se soustrait  clocktree.h
    SysCtl_setEPWMClockDivider(SYSCTL_EPWMCLK_DIV_2);                           // non gnr par SYSCONFIG dans clocktree.h, non inclus dans Device_init();

    //
    // Disable pin locks and enable internal pull-ups.
    //
    Device_initGPIO();

    //
    // Initialize PIE and clear PIE registers. Disables CPU interrupts.
    //
    Interrupt_initModule();

    //
    // Initialize the PIE vector table with pointers to the shell Interrupt
    // Service Routines (ISR).
    //
    Interrupt_initVectorTable();


    // INITIALISATIONS CARTE PAR SYSCONFIG
    // ------------------------------------
    Board_init();

    // INITIALISATIONS CARTE PAR SYSCONFIG
    // ------------------------------------
    C2000Ware_libraries_init();

    // Enable Global Interrupt (INTM) and real time interrupt (DBGM)
    // ---------------------------------------------------------------
    EINT;
    ERTM;


    flt_CANTX=0.0;

    while(1)
    {


    }

}



/* ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 * FONCTION INTERRUPT EPWM7 (GROUPE 3)
 *
 * - changement de l'tat de la LED si confirmation appui BP
 *
 *
 * ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 */

__interrupt void INT_myEPWMTimer0_ISR(void)
{
    GPIO_togglePin(myLEDBlue);

    flt_CANTX=flt_CANTX+0.1;

    Uint32 uint32_CANTX=__f32_bits_as_u32(flt_CANTX );      // fonction intrinsque, pas de code (juste dire au compilateur comment interprter la variable)

    GPIO_togglePin(DEBUG2);
    LIEB_FloatToUint8Tab(flt_CANTX,txMsgData,0);

    CAN_sendMessage(myCAN_BASE, 1, 8,txMsgData);


    EPWM_clearEventTriggerInterruptFlag(myEPWMTimer0_BASE);

    Interrupt_clearACKGroup(INT_myEPWMTimer0_INTERRUPT_ACK_GROUP);         // Acquittement de l'interruption du groupe (permet la Request d'une autre surce du mme groupe)

}


/* ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 * FONCTION INTERRUPT CANTX LINE 0
 *
 *
 * ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 */

__interrupt void INT_myCAN_0_ISR(void)
{


    Interrupt_clearACKGroup(INT_myCAN_0_INTERRUPT_ACK_GROUP);
}

/* ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 * FONCTION INTERRUPT CANTX LINE 1
 *
 *
 * ---------------------------------------------------------------------------------------------------------------------------------
 * ---------------------------------------------------------------------------------------------------------------------------------
 */

__interrupt void INT_myCAN_1_ISR(void)
{
    uint32_t status;

    status = CAN_getInterruptCause(myCAN_BASE);
    CAN_clearInterruptStatus(myCAN_BASE, 1);

    /*if(status == 1)
    {
        CAN_clearInterruptStatus(myCAN_BASE, 1);
    }*/
    GPIO_togglePin(DEBUG5);
    CAN_clearGlobalInterruptStatus(myCAN_BASE, CAN_GLOBAL_INT_CANINT1);
    Interrupt_clearACKGroup(INT_myCAN_1_INTERRUPT_ACK_GROUP);
}



//
// End of File
//
